@@ -257,7 +257,7 @@ class SchemaForm(dbc.Card):
 
         # Unique Card IDs are composed by parent id + key from json schema
         if parent_form is None:
-            self.id = key
+            self.id = f'{container.id}-{key}'
             self.container = container
         else:
             self.id = parent_form.id + '-' + key
@@ -346,7 +346,7 @@ class SchemaFormContainer(html.Div):
     id + '-external-trigger-update-links-values'
     """
 
-    def __init__(self, id, schema, parent_app):
+    def __init__(self, id, schema, parent_app, root_path=None):
         super().__init__([])
 
         self.id = id
@@ -354,6 +354,12 @@ class SchemaFormContainer(html.Div):
         self.parent_app = parent_app
         self.data = {}
         self.children_forms = []
+
+        if root_path is not None:
+            self.parent_app.server.config['DATA_PATH'] = root_path
+        else:
+            self.parent_app.server.config['DATA_PATH'] = Path.cwd()
+
         self.root_path = Path(self.parent_app.server.config['DATA_PATH']).parent
 
         # Hidden components that serve to trigger callbacks
@@ -469,6 +475,10 @@ class SchemaFormContainer(html.Div):
         def update_forms_values(trigger, trigger_all, *states):
             ctx = dash.callback_context
             trigger_source = ctx.triggered[0]['prop_id'].split('.')[0]
+
+            if not trigger_source:
+                return dash.no_update
+
             context = json.loads(trigger_source)
 
             if context['type'] == 'external-trigger-update-forms-values' and all((trg is None) or trg == [] for trg in trigger):
@@ -568,10 +578,21 @@ class SchemaFormContainer(html.Div):
 
             return output
 
+    def update_lists_data(self, v, key, k):
+        for i, e in enumerate(v):
+            for i_key, i_value in e.items():
+                if isinstance(i_value, list):
+                    inner_key = f'{key}-{k}-{i}'
+                    self.update_lists_data(i_value, inner_key, i_key)
+                else:
+                    component_id = f'{key}-{k}-{i}-{i_key}'
+                    self.data[component_id]['value'] = i_value
+        return
+
     def update_data(self, data, key=None):
         """Update data in the internal mapping dictionary of this Container"""
         if key is None:
-            key = ''
+            key = self.id
 
         # Update dict with incoming data
         for k, v in data.items():
@@ -584,10 +605,7 @@ class SchemaFormContainer(html.Div):
                 self.update_data(data=v, key=inner_key)
             # If value is a list of dicts
             elif isinstance(v, list) and len(v) > 0 and isinstance(v[0], dict):
-                for i, e in enumerate(v):
-                    for i_key, i_value in e.items():
-                        component_id = f'{key}-{k}-{i}-{i_key}'
-                        self.data[component_id]['value'] = i_value
+                self.update_lists_data(v, key, k)
             # If value is a string, number, list of strings or boolean
             else:
                 component_id = key + '-' + k  # e.g. NWBFile-session_description
@@ -641,9 +659,10 @@ class SchemaFormContainer(html.Div):
                 for element in reversed(splited_keys):
                     if element == field_name:
                         curr_dict = {field_name: v['value']}
-                    else:
+                    elif element != master_key_name:
                         curr_dict = {element: curr_dict}
-                    if element == master_key_name:
+                    else:
+                    #if element == master_key_name:
                         dicts_list.append(curr_dict)
 
         for e in dicts_list:
